"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NestableDraggableFlatList = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = require("react-native-reanimated");

var _DraggableFlatList = _interopRequireDefault(require("../components/DraggableFlatList"));

var _nestableScrollContainerContext = require("../context/nestableScrollContainerContext");

var _useNestedAutoScroll = require("../hooks/useNestedAutoScroll");

var _utils = require("../utils");

var _useIdentityRetainingCallback = require("../hooks/useIdentityRetainingCallback");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function NestableDraggableFlatListInner(props) {
  const hasSuppressedWarnings = (0, _react.useRef)(false);

  if (!hasSuppressedWarnings.current) {
    _reactNative.LogBox.ignoreLogs(["VirtualizedLists should never be nested inside plain ScrollViews with the same orientation because it can break windowing"]); // Ignore log notification by message
    //@ts-ignore


    console.reportErrorsAsExceptions = false;
    hasSuppressedWarnings.current = true;
  }

  const {
    scrollableRef,
    outerScrollOffset,
    setOuterScrollEnabled
  } = (0, _nestableScrollContainerContext.useSafeNestableScrollContainerContext)();
  const listVerticalOffset = (0, _reactNativeReanimated.useSharedValue)(0);
  const [animVals, setAnimVals] = (0, _react.useState)({});
  const defaultHoverOffset = (0, _reactNativeReanimated.useSharedValue)(0);
  const [listHoverOffset, setListHoverOffset] = (0, _react.useState)(defaultHoverOffset);
  const hoverOffset = (0, _reactNativeReanimated.useDerivedValue)(() => {
    return listHoverOffset.value + listVerticalOffset.value;
  }, [listHoverOffset]);
  (0, _useNestedAutoScroll.useNestedAutoScroll)({ ...animVals,
    hoverOffset
  });
  const onListContainerLayout = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(async _ref => {
    let {
      containerRef
    } = _ref;
    const nodeHandle = (0, _reactNative.findNodeHandle)(scrollableRef.current);

    const onSuccess = (_x, y) => {
      listVerticalOffset.value = y;
    };

    const onFail = () => {
      console.log("## nested draggable list measure fail");
    }; //@ts-ignore


    containerRef.current.measureLayout(nodeHandle, onSuccess, onFail);
  });
  const onDragBegin = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(params => {
    var _props$onDragBegin;

    setOuterScrollEnabled(false);
    (_props$onDragBegin = props.onDragBegin) === null || _props$onDragBegin === void 0 ? void 0 : _props$onDragBegin.call(props, params);
  });
  const onDragEnd = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(params => {
    var _props$onDragEnd;

    setOuterScrollEnabled(true);
    (_props$onDragEnd = props.onDragEnd) === null || _props$onDragEnd === void 0 ? void 0 : _props$onDragEnd.call(props, params);
  });
  const onAnimValInit = (0, _useIdentityRetainingCallback.useIdentityRetainingCallback)(params => {
    var _props$onAnimValInit;

    setListHoverOffset(params.hoverOffset);
    setAnimVals({ ...params,
      hoverOffset
    });
    (_props$onAnimValInit = props.onAnimValInit) === null || _props$onAnimValInit === void 0 ? void 0 : _props$onAnimValInit.call(props, params);
  });
  return /*#__PURE__*/_react.default.createElement(_DraggableFlatList.default, _extends({
    onContainerLayout: onListContainerLayout,
    activationDistance: props.activationDistance || 20,
    scrollEnabled: false
  }, props, {
    outerScrollOffset: outerScrollOffset,
    onDragBegin: onDragBegin,
    onDragEnd: onDragEnd,
    onAnimValInit: onAnimValInit
  }));
}

const NestableDraggableFlatList = (0, _utils.typedMemo)(NestableDraggableFlatListInner);
exports.NestableDraggableFlatList = NestableDraggableFlatList;
//# sourceMappingURL=NestableDraggableFlatList.js.map